@@ -3,7 +3,9 @@
 
 #include <QMainWindow>
 #include <QDebug>
+#include <QSettings>
 #include <qfacebook.h>
+#include "newsfeedpost.h"
 
 namespace Ui {
     class MessageView;
@@ -23,6 +25,9 @@ private:
     QString accessToken;
     QFacebook *qfacebook;
     QFacebookReply *reply;
+    QList<NewsFeedPost*> messages;
+    QNetworkAccessManager *nam;
+    QString myId;
 
 private slots:
     void onReplyReceived();
