@@ -114,8 +114,13 @@ void NewsFeedPost::setDeletable(bool deletable)
 
 void NewsFeedPost::setAvatar(QPixmap pixmap)
 {
+    QPropertyAnimation *animation = new QPropertyAnimation(ui->avatarLabel, "pos", this);
+    animation->setStartValue(QPoint(ui->avatarLabel->x(), ui->avatarLabel->y()-(ui->avatarLabel->height()+70)));
+    animation->setEndValue(ui->avatarLabel->pos());
+    animation->setDuration(1000);
+    animation->setEasingCurve(QEasingCurve::InOutBack);
+    animation->start(QPropertyAnimation::DeleteWhenStopped);
     ui->avatarLabel->setPixmap(pixmap);
-    ui->avatarLabel->show();
 }
 
 void NewsFeedPost::setMessage(QString message)
@@ -266,3 +271,15 @@ void NewsFeedPost::mouseReleaseEvent(QMouseEvent *ev)
         }
     }
 }
+
+void NewsFeedPost::showEvent(QShowEvent *)
+{
+#ifndef Q_WS_MAEMO_5
+    QPropertyAnimation *animation = new QPropertyAnimation(this, "pos", this);
+    animation->setStartValue(QPoint(this->x()-this->width(), this->y()));
+    animation->setEndValue(this->pos());
+    animation->setDuration(1000);
+    animation->setEasingCurve(QEasingCurve::OutCubic);
+    animation->start(QPropertyAnimation::DeleteWhenStopped);
+#endif
+}
