@@ -8,6 +8,7 @@
 #include <QDateTime>
 #include <QPainter>
 #include <QMainWindow>
+#include <QPropertyAnimation>
 #ifdef Q_WS_MAEMO_5
     #include <QMaemo5InformationBox>
 #endif
@@ -46,6 +47,7 @@ protected:
     void resizeEvent(QResizeEvent *);
     void mousePressEvent(QMouseEvent *);
     void mouseReleaseEvent(QMouseEvent *);
+    void showEvent(QShowEvent *);
 
 signals:
     void commentButtonClicked(QString id, QString comments, QString likes);
