@@ -10,6 +10,8 @@
 #include <qfacebook.h>
 
 #include "widgets/placeitem.h"
+#include "checkindialog.h"
+#include "checkinwindow.h"
 
 #ifdef MOBILITY
     QTM_USE_NAMESPACE
@@ -26,6 +28,9 @@ public:
     explicit PlacesWindow(QWidget *parent = 0, QString token = "0");
     ~PlacesWindow();
 
+signals:
+    void coordinatesChanged(double, double);
+
 protected:
     void closeEvent(QCloseEvent *);
 
@@ -39,12 +44,17 @@ private:
     QFacebookReply *reply;
     double longitude;
     double latitude;
+    QList<PlaceItem*> checkins;
+    QNetworkAccessManager *nam;
 
 private slots:
 #ifdef MOBILITY
     void onPositionUpdated(QGeoPositionInfo info);
 #endif
     void onSearchReplyReceived();
+    void updateRecentCheckins();
+    void checkIn();
+    void onPlaceSelected(QString name, QString id, QString longitude, QString latitude);
 };
 
 #endif // PLACESWINDOW_H
